@@ -102,9 +102,6 @@ class Database:
                     qfq_df['index'] = qfq_df['index'].str.replace('-', '', regex=False)
                     df = pd.merge(left=df, left_on='date', right=qfq_df, right_on='index')
 
-                    print(df)
-                    time.sleep(132456)
-
                     if df['qfq_factor'].isnull().values.any():
                         df['qfq_factor'] = df['qfq_factor'].fillna(method='ffill')
 
